==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Move or copy" : "Verplaats of kopieer",
    "Download" : "Downloaden",
    "Delete" : "Verwijderen",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Favorites" : "Favorieten",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "This will stop your current uploads." : "Dit beëindigt onderhanden uploads",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Processing files …" : "Verwerken bestanden ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. Je uploadt {size1}, maar er is slechts {size2} beschikbaar",
    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet meer",
    "Not enough free space" : "Onvoldoende vrije ruimte",
    "An unknown error has occurred" : "Er trad een onbekende fout op.",
    "Uploading …" : "Uploaden …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uploaden van dat object is niet ondersteund",
    "Target folder does not exist any more" : "Doelmap bestaat niet meer",
    "Operation is blocked by access control" : "De operatie werd tegengehouden door toegangscontrole",
    "Error when assembling chunks, status code {status}" : "Fout tijdens samenvoegen van brokken, status code {status}",
    "Actions" : "Acties",
    "Rename" : "Naam wijzigen",
    "Copy" : "Kopiëren",
    "Choose target folder" : "Kies doelmap…",
    "Open" : "Openen",
    "Delete file" : "Verwijderen bestand",
    "Delete folder" : "Verwijderen map",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Leave this share" : "Verlaat deze gedeelde locatie",
    "Could not load info for file \"{file}\"" : "Kon geen informatie laden voor bestand \"{file}\"",
    "Files" : "Bestanden",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "copy" : "kopiëren",
    "Could not copy \"{file}\", target exists" : "Kon \"{bestand}\" niet kopiëren, het doel bestaat",
    "Could not copy \"{file}\"" : "Kon \"{file}\" niet kopiëren",
    "Copied {origin} inside {destination}" : "Kopieerde {oorsprong} binnen {bestemming}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Heeft {andere} en {nbfiles} andere bestanden in {destination} gekopieerd",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon \"{fileName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Could not fetch file details \"{file}\"" : "Kon details van \"{file}\" niet ophalen",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Geen zoekresultaten voor {tag}{filter}{endtag} in andere mappen",
    "Enter more than two characters to search in other folders" : "Voer meer dan twee tekens in om in andere mappen te zoeken",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclusief %n verborgen","inclusief %n verborgen"],
    "You don’t have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "Select file range" : "Kies een reeks bestanden",
    "{used} of {quota} used" : "{used} van {quota} gebruikt",
    "{used} used" : "{used} gebruikt",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "\"/\" is not allowed inside a file name." : "\"/\" is niet toegestaan binnen een bestandsnaam.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" bestandstype is een niet toegestaande",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden geüpload of gesynchroniseerd!",
    "Your storage is full, files can not be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)." : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "View in folder" : "Bekijken in map",
    "Copied!" : "Gekopieerd!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopieer de link direct (werkt alleen voor gebruikers met toegang tot map/bestand)",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "You can only favorite a single file or folder at a time" : "Je kunt maar één bestand of map tegelijk favoriet maken",
    "New folder" : "Nieuwe map",
    "Upload file" : "Bestand uploaden",
    "Recent" : "Recent",
    "Not favorited" : "Niet in favorieten",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Aan favorieten toevoegen",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij je poging om de tags bij te werken",
    "Added to favorites" : "Aan favorieten toegevoegd",
    "Removed from favorites" : "Uit favorieten verwijderd",
    "You added {file} to your favorites" : "Je voegde {file} toe aan favorieten",
    "You removed {file} from your favorites" : "Je verwijderde {file} uit je favorieten",
    "File changes" : "Bestandswijzigingen",
    "Created by {user}" : "Gecreëerd door {user}",
    "Changed by {user}" : "Gewijzigd door {user}",
    "Deleted by {user}" : "Verwijderd door {user}",
    "Restored by {user}" : "Hersteld door {user}",
    "Renamed by {user}" : "Hernoemd door {user}",
    "Moved by {user}" : "Verplaatst door {user}",
    "\"remote user\"" : "\"externe gebruiker\"",
    "You created {file}" : "Je creëerde {file}",
    "You created an encrypted file in {file}" : "Je creëerde een versleuteld bestand in {file}",
    "{user} created {file}" : "{user} creëerde {file}",
    "{user} created an encrypted file in {file}" : "{user} creëerde een versleuteld bestand in {file}",
    "{file} was created in a public folder" : "{file} werd gecreëerd in een openbare map",
    "You changed {file}" : "Je wijzigde {file}",
    "You changed an encrypted file in {file}" : "Je wijzigde een versleuteld bestand in {file}",
    "{user} changed {file}" : "{user} wijzigde {file}",
    "{user} changed an encrypted file in {file}" : "{user} heeft een versleuteteld bestand veranderd in {file}",
    "You deleted {file}" : "Je verwijderde {file}",
    "You deleted an encrypted file in {file}" : "Je hebt een versleuteld bestand gewist in {file}",
    "{user} deleted {file}" : "{user} verwijderde {file}",
    "{user} deleted an encrypted file in {file}" : "{user} heeft een versleuteld bestand gewist in {file}",
    "You restored {file}" : "Je herstelde {file}",
    "{user} restored {file}" : "{user} herstelde {file}",
    "You renamed {oldfile} to {newfile}" : "Je hernoemde {oldfile} naar {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} hernoemde {oldfile} naar {newfile}",
    "You moved {oldfile} to {newfile}" : "Je verplaatste {oldfile} naar {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} verplaatste {oldfile} naar {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Een bestand werd toegevoegd of verwijderd van je <strong>favorieten</strong>",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Een favoriet bestand of map is <strong>gewijzigd</strong>",
    "All files" : "Alle bestanden",
    "Unlimited" : "Ongelimiteerd",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accepteren",
    "Reject" : "Afwijzen",
    "Incoming ownership transfer from {user}" : "Inkomend verzoek om eigenaarsoverdracht van {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Wil je {path} accepteren? \n\nOpmerking: het overdrachtsproces na acceptatie kan tot 1 uur duren.",
    "Ownership transfer failed" : "Eigenaarschap overdracht mislukt",
    "Your ownership transfer of {path} to {user} failed." : "Eigenaarsoverdracht van {path} naar {user} is mislukt.",
    "The ownership transfer of {path} from {user} failed." : "Eigenaarsoverdracht van {path} van {user} is mislukt.",
    "Ownership transfer done" : "Eigenaarschap overdracht geslaagd",
    "Your ownership transfer of {path} to {user} has completed." : "Eigenaarsoverdracht van {path} naar {user} is gereed.",
    "The ownership transfer of {path} from {user} has completed." : "Eigenaarsoverdracht van {path} van {user} is gereed.",
    "in %s" : "in %s",
    "File Management" : "Bestandsbeheer",
    "Transfer ownership of a file or folder" : "Overdragen eigenaarschap bestand of map ",
    "Choose file or folder to transfer" : "Kies over te dragen bestand of map",
    "Change" : "Pas aan",
    "New owner" : "Nieuwe eigenaar",
    "Search users" : "Gebruikers zoeken",
    "Choose a file or folder to transfer" : "Kies een bestand of map om over te dragen",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Draag {path} over aan {userid}",
    "Invalid path selected" : "Ongeldig pad geselecteerd",
    "Ownership transfer request sent" : "Aanvraag eigenaarsoverdracht verstuurd",
    "Cannot transfer ownership of a file or folder you don't own" : "Kan het eigenaarschap van een bestand of map waarvan u niet de eigenaar bent, niet overdragen",
    "Tags" : "Tags",
    "Unable to change the favourite state of the file" : "Niet mogelijk om favoriet status van het bestand te wijzigen",
    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
    "%s used" : "%s gebruikt",
    "%s%% of %s used" : "%s%% van %s gebruikt",
    "%1$s of %2$s used" : "%1$s van %2$s gebruikt",
    "Settings" : "Instellingen",
    "Show hidden files" : "Verborgen bestanden tonen",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Gebruik dit adres om je bestanden via WebDAV te benaderen",
    "Toggle grid view" : "Omschakelen roosterweergave",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "No favorites yet" : "Nog geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
    "Deleted files" : "Verwijderde bestanden",
    "Shares" : "Shares",
    "Shared with others" : "Gedeeld met anderen",
    "Shared with you" : "Gedeeld met jou",
    "Shared by link" : "Gedeeld via link",
    "Deleted shares" : "Verwijderde shares",
    "Pending shares" : "Deellinks in behandeling",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "Unshare" : "Stop met delen",
    "This group folder is full, files can not be updated or synced anymore!" : "Deze groepsmap is vol, bestanden kunnen niet meer bijgewerkt of gesynchroniseerd worden!",
    "This external storage is full, files can not be updated or synced anymore!" : "Deze externe opslag is vol, bestanden kunnen niet meer bijgewerkt of gesynchroniseerd worden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "This group folder is almost full ({usedSpacePercent}%)" : "Deze groepsfolder zit bijna vol ({usedSpacePercent}%)",
    "This external storage is almost full ({usedSpacePercent}%)" : "Deze externe opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Een bestand of map is <strong>gewijzigd</strong> of <strong>hernoemd</strong>",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan je <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
    "Cannot transfter ownership of a file or folder you don't own" : "Kan het eigenaarschap van een bestand of map waarvan u niet de eigenaar bent, niet overdragen",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">om je bestanden te benaderen via WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Move or copy" : "Verplaats of kopieer",
    "Download" : "Downloaden",
    "Delete" : "Verwijderen",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Favorites" : "Favorieten",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "This will stop your current uploads." : "Dit beëindigt onderhanden uploads",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Processing files …" : "Verwerken bestanden ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. Je uploadt {size1}, maar er is slechts {size2} beschikbaar",
    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet meer",
    "Not enough free space" : "Onvoldoende vrije ruimte",
    "An unknown error has occurred" : "Er trad een onbekende fout op.",
    "Uploading …" : "Uploaden …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uploaden van dat object is niet ondersteund",
    "Target folder does not exist any more" : "Doelmap bestaat niet meer",
    "Operation is blocked by access control" : "De operatie werd tegengehouden door toegangscontrole",
    "Error when assembling chunks, status code {status}" : "Fout tijdens samenvoegen van brokken, status code {status}",
    "Actions" : "Acties",
    "Rename" : "Naam wijzigen",
    "Copy" : "Kopiëren",
    "Choose target folder" : "Kies doelmap…",
    "Open" : "Openen",
    "Delete file" : "Verwijderen bestand",
    "Delete folder" : "Verwijderen map",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Leave this share" : "Verlaat deze gedeelde locatie",
    "Could not load info for file \"{file}\"" : "Kon geen informatie laden voor bestand \"{file}\"",
    "Files" : "Bestanden",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "copy" : "kopiëren",
    "Could not copy \"{file}\", target exists" : "Kon \"{bestand}\" niet kopiëren, het doel bestaat",
    "Could not copy \"{file}\"" : "Kon \"{file}\" niet kopiëren",
    "Copied {origin} inside {destination}" : "Kopieerde {oorsprong} binnen {bestemming}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Heeft {andere} en {nbfiles} andere bestanden in {destination} gekopieerd",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon \"{fileName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Could not fetch file details \"{file}\"" : "Kon details van \"{file}\" niet ophalen",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Geen zoekresultaten voor {tag}{filter}{endtag} in andere mappen",
    "Enter more than two characters to search in other folders" : "Voer meer dan twee tekens in om in andere mappen te zoeken",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclusief %n verborgen","inclusief %n verborgen"],
    "You don’t have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "Select file range" : "Kies een reeks bestanden",
    "{used} of {quota} used" : "{used} van {quota} gebruikt",
    "{used} used" : "{used} gebruikt",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "\"/\" is not allowed inside a file name." : "\"/\" is niet toegestaan binnen een bestandsnaam.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" bestandstype is een niet toegestaande",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden geüpload of gesynchroniseerd!",
    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Groepsmap \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Externe opslag \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
    "Your storage is full, files can not be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Groepsmap \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externe opslag \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "View in folder" : "Bekijken in map",
    "Copied!" : "Gekopieerd!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopieer de link direct (werkt alleen voor gebruikers met toegang tot map/bestand)",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "You can only favorite a single file or folder at a time" : "Je kunt maar één bestand of map tegelijk favoriet maken",
    "New folder" : "Nieuwe map",
    "Upload file" : "Bestand uploaden",
    "Recent" : "Recent",
    "Not favorited" : "Niet in favorieten",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Aan favorieten toevoegen",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij je poging om de tags bij te werken",
    "Added to favorites" : "Aan favorieten toegevoegd",
    "Removed from favorites" : "Uit favorieten verwijderd",
    "You added {file} to your favorites" : "Je voegde {file} toe aan favorieten",
    "You removed {file} from your favorites" : "Je verwijderde {file} uit je favorieten",
    "File changes" : "Bestandswijzigingen",
    "Created by {user}" : "Gecreëerd door {user}",
    "Changed by {user}" : "Gewijzigd door {user}",
    "Deleted by {user}" : "Verwijderd door {user}",
    "Restored by {user}" : "Hersteld door {user}",
    "Renamed by {user}" : "Hernoemd door {user}",
    "Moved by {user}" : "Verplaatst door {user}",
    "\"remote user\"" : "\"externe gebruiker\"",
    "You created {file}" : "Je creëerde {file}",
    "You created an encrypted file in {file}" : "Je creëerde een versleuteld bestand in {file}",
    "{user} created {file}" : "{user} creëerde {file}",
    "{user} created an encrypted file in {file}" : "{user} creëerde een versleuteld bestand in {file}",
    "{file} was created in a public folder" : "{file} werd gecreëerd in een openbare map",
    "You changed {file}" : "Je wijzigde {file}",
    "You changed an encrypted file in {file}" : "Je wijzigde een versleuteld bestand in {file}",
    "{user} changed {file}" : "{user} wijzigde {file}",
    "{user} changed an encrypted file in {file}" : "{user} heeft een versleuteteld bestand veranderd in {file}",
    "You deleted {file}" : "Je verwijderde {file}",
    "You deleted an encrypted file in {file}" : "Je hebt een versleuteld bestand gewist in {file}",
    "{user} deleted {file}" : "{user} verwijderde {file}",
    "{user} deleted an encrypted file in {file}" : "{user} heeft een versleuteld bestand gewist in {file}",
    "You restored {file}" : "Je herstelde {file}",
    "{user} restored {file}" : "{user} herstelde {file}",
    "You renamed {oldfile} to {newfile}" : "Je hernoemde {oldfile} naar {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} hernoemde {oldfile} naar {newfile}",
    "You moved {oldfile} to {newfile}" : "Je verplaatste {oldfile} naar {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} verplaatste {oldfile} naar {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Een bestand werd toegevoegd of verwijderd van je <strong>favorieten</strong>",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Een favoriet bestand of map is <strong>gewijzigd</strong>",
    "All files" : "Alle bestanden",
    "Unlimited" : "Ongelimiteerd",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accepteren",
    "Reject" : "Afwijzen",
    "Incoming ownership transfer from {user}" : "Inkomend verzoek om eigenaarsoverdracht van {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Wil je {path} accepteren? \n\nOpmerking: het overdrachtsproces na acceptatie kan tot 1 uur duren.",
    "Ownership transfer failed" : "Eigenaarschap overdracht mislukt",
    "Your ownership transfer of {path} to {user} failed." : "Eigenaarsoverdracht van {path} naar {user} is mislukt.",
    "The ownership transfer of {path} from {user} failed." : "Eigenaarsoverdracht van {path} van {user} is mislukt.",
    "Ownership transfer done" : "Eigenaarschap overdracht geslaagd",
    "Your ownership transfer of {path} to {user} has completed." : "Eigenaarsoverdracht van {path} naar {user} is gereed.",
    "The ownership transfer of {path} from {user} has completed." : "Eigenaarsoverdracht van {path} van {user} is gereed.",
    "in %s" : "in %s",
    "File Management" : "Bestandsbeheer",
    "Transfer ownership of a file or folder" : "Overdragen eigenaarschap bestand of map ",
    "Choose file or folder to transfer" : "Kies over te dragen bestand of map",
    "Change" : "Pas aan",
    "New owner" : "Nieuwe eigenaar",
    "Search users" : "Gebruikers zoeken",
    "Choose a file or folder to transfer" : "Kies een bestand of map om over te dragen",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Draag {path} over aan {userid}",
    "Invalid path selected" : "Ongeldig pad geselecteerd",
    "Ownership transfer request sent" : "Aanvraag eigenaarsoverdracht verstuurd",
    "Cannot transfer ownership of a file or folder you don't own" : "Kan het eigenaarschap van een bestand of map waarvan u niet de eigenaar bent, niet overdragen",
    "Tags" : "Tags",
    "Unable to change the favourite state of the file" : "Niet mogelijk om favoriet status van het bestand te wijzigen",
    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
    "%s used" : "%s gebruikt",
    "%s%% of %s used" : "%s%% van %s gebruikt",
    "%1$s of %2$s used" : "%1$s van %2$s gebruikt",
    "Settings" : "Instellingen",
    "Show hidden files" : "Verborgen bestanden tonen",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Gebruik dit adres om je bestanden via WebDAV te benaderen",
    "Toggle grid view" : "Omschakelen roosterweergave",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "No favorites yet" : "Nog geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
    "Deleted files" : "Verwijderde bestanden",
    "Shares" : "Shares",
    "Shared with others" : "Gedeeld met anderen",
    "Shared with you" : "Gedeeld met jou",
    "Shared by link" : "Gedeeld via link",
    "Deleted shares" : "Verwijderde shares",
    "Pending shares" : "Deellinks in behandeling",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "Unshare" : "Stop met delen",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Een bestand of map is <strong>gewijzigd</strong> of <strong>hernoemd</strong>",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan je <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
    "Cannot transfter ownership of a file or folder you don't own" : "Kan het eigenaarschap van een bestand of map waarvan u niet de eigenaar bent, niet overdragen",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">om je bestanden te benaderen via WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");
